//###########################################################################
//
// FILE:	DSP281x_Adc.c
//
// TITLE:	DSP281x ADC Initialization & Support Functions.
//###########################################################################

#include "DSP281x_Device.h"     // DSP281x Headerfile Include File
#include "DSP281x_Examples.h"   // DSP281x Examples Include File

#define ADC_usDELAY  8000L
#define ADC_usDELAY2 20L

//---------------------------------------------------------------------------
// InitAdc: 
//---------------------------------------------------------------------------
// This function initializes ADC to a known state.
//
void InitAdc(void)
{
	extern void DSP28x_usDelay(Uint32 Count);
	
	// select Reference Voltage
 	AdcRegs.ADCTRL3.bit.EXTREF = 0;			// Internal Reference Voltage


    // To powerup the ADC the ADCENCLK bit should be set first to enable
    // clocks, followed by powering up the bandgap and reference circuitry.
    // After a 5ms delay the rest of the ADC can be powered up. After ADC
    // powerup, another 20us delay is required before performing the first
    // ADC conversion. Please note that for the delay function below to
    // operate correctly the CPU_CLOCK_SPEED define statement in the
    // DSP28_Examples.h file must contain the correct CPU clock period in
    // nanoseconds. For example:

	AdcRegs.ADCTRL3.bit.ADCBGRFDN = 0x3;	// Power up bandgap/reference circuitry
	DELAY_US(ADC_usDELAY);                  // Delay before powering up rest of ADC
	AdcRegs.ADCTRL3.bit.ADCPWDN = 1;		// Power up rest of ADC
	DELAY_US(ADC_usDELAY2);                 // Delay after powering up ADC



	// set sample switch close time
 	AdcRegs.ADCTRL1.bit.ACQ_PS = 0;			// + 1 ADCCLK period

	// set ADCCLK prescaler
	// ADCLK = HSPCLK / (ADCCLKPS * (ADCTRL1[7] + 1))
	// see spru060D, p. 2.9
	AdcRegs.ADCTRL3.bit.ADCCLKPS = 3;		// prescaler /6
	AdcRegs.ADCTRL1.bit.CPS = 0;			// additional /2 deactiv.

	// set sampling mode
 	AdcRegs.ADCTRL3.bit.SMODE_SEL = 1;		// simultanious sampling mode

	// set cascaded seq = seq1 + seq2
	AdcRegs.ADCTRL1.bit.SEQ_CASC = 1;		// cascaded sequencer mode


	// configure ADC
	AdcRegs.ADCMAXCONV.all = 0x0007;        // 8 simultaneous sample pairs, 16 total

	AdcRegs.ADCCHSELSEQ1.bit.CONV00 = 0x0;  // Setup conv from ADCINA0 and ADCINB0
	AdcRegs.ADCCHSELSEQ1.bit.CONV01 = 0x1;  // Setup conv from ADCINA1 and ADCINB1
	AdcRegs.ADCCHSELSEQ1.bit.CONV02 = 0x2;  // Setup conv from ADCINA2 and ADCINB2
	AdcRegs.ADCCHSELSEQ1.bit.CONV03 = 0x3;  // Setup conv from ADCINA3 and ADCINB3
	AdcRegs.ADCCHSELSEQ2.bit.CONV04 = 0x4;	// Setup conv from ADCINA4 and ADCINB4
	AdcRegs.ADCCHSELSEQ2.bit.CONV05 = 0x5;	// Setup conv from ADCINA5 and ADCINB5
	AdcRegs.ADCCHSELSEQ2.bit.CONV06 = 0x6;	// Setup conv from ADCINA6 and ADCINB6
	AdcRegs.ADCCHSELSEQ2.bit.CONV07 = 0x7;	// Setup conv from ADCINA7 and ADCINB7
	AdcRegs.ADCTRL2.bit.INT_ENA_SEQ1 = 1;	// enable SEQ1 interrupt

	// ADC start condition is Timer1
	//EvaRegs.GPTCONA.bit.T1TOADC = 1;		// start with period interrupt bit

	// write a '1' to reset the INT SEQ1 flag (!)
	AdcRegs.ADCST.bit.INT_SEQ1_CLR = 1;

	// enable EVA start of converion to start SEQ1
	AdcRegs.ADCTRL2.bit.EVA_SOC_SEQ1 = 1;

	// enable PIE group 1 interrupt 6 for ADCINT
	PieCtrlRegs.PIEIER1.all |= M_INT6;

	// enable CPU INT1 for PIE group 1 interrupt
	IER |= M_INT1;
}

//===========================================================================
// No more.
//===========================================================================
