#include <math.h>
#include <float.h>
#include <stdlib.h>
#include <time.h>
#include <stdio.h>

// TI
#include "DSP281x_Device.h"
#include "DSP281x_Examples.h"

void init_pwm(void);
int test1;
extern void DSP28x_usDelay(Uint32 Count);

void main(void)
{

// Step 1. Initialize System Control:
// PLL, WatchDog, enable Peripheral Clocks
// This example function is found in the DSP281x_SysCtrl.c file.
   InitSysCtrl();

// Step 2. Initalize GPIO: 
// This example function is found in the DSP281x_Gpio.c file and
// illustrates how to set the GPIO to it's default state.
// InitGpio();  // Skipped for this example  

// Initialize only GPAMUX and GPBMUX for this test
   EALLOW;
   // Enable PWM pins
   GpioMuxRegs.GPAMUX.all = 0x00FF; // EVA PWM 1-6  pins
   GpioMuxRegs.GPBMUX.all = 0x00FF; // EVB PWM 7-12 pins
   EDIS;
    
// Step 3. Clear all interrupts and initialize PIE vector table:
// Disable CPU interrupts 
   DINT;

// Initialize PIE control registers to their default state.
// The default state is all PIE interrupts disabled and flags
// are cleared.  
// This function is found in the DSP281x_PieCtrl.c file.
   InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags:
   IER = 0x0000;
   IFR = 0x0000;

// Initialize the PIE vector table with pointers to the shell Interrupt 
// Service Routines (ISR).  
// This will populate the entire table, even if the interrupt
// is not used in this example.  This is useful for debug purposes.
// The shell ISR routines are found in DSP281x_DefaultIsr.c.
// This function is found in DSP281x_PieVect.c.
   InitPieVectTable();
   
// Step 4. Initialize all the Device Peripherals:
// This function is found in DSP281x_InitPeripherals.c

   InitPeripherals();
   init_pwm();

// Step 5. User specific code, enable interrupts:


  // Just sit and loop forever:
  // PWM pins can be observed with a scope.

DINT;
EALLOW;
GpioMuxRegs.GPBMUX.bit.TCLKINB_GPIOB12=0;  	// SET PIN_B_12 as GPIO
GpioMuxRegs.GPBDIR.bit.GPIOB12=1;   		// GPIO DIR select GPIOs as output
EDIS;

	while(1)
	{
		GpioDataRegs.GPBSET.bit.GPIOB12=1;
		DELAY_US(100);
		test1=1;
		GpioDataRegs.GPBCLEAR.bit.GPIOB12=1;
		DELAY_US(100);
		test1=0;
	}
//  for(;;);

}

void init_pwm()
{

// EVA Configure T1PWM, T2PWM, PWM1-PWM6 
// Initalize the timers
   
// Initalize EVA PWM Timer
	// Action an compare output
	EvaRegs.ACTRA.bit.CMP1ACT = 2;	// Pin 1 active high
	EvaRegs.ACTRA.bit.CMP2ACT = 2;	// Pin 2 active high
	EvaRegs.ACTRA.bit.CMP3ACT = 2;	// Pin 3 active high
	EvaRegs.ACTRA.bit.CMP4ACT = 2;	// Pin 4 active high
	EvaRegs.ACTRA.bit.CMP5ACT = 2;	// Pin 5 active high
	EvaRegs.ACTRA.bit.CMP6ACT = 2;	// Pin 6 active high

	// Config of compare-control-register
	EvaRegs.COMCONA.bit.CENABLE = 1;	// Compare enable
	EvaRegs.COMCONA.bit.SVENABLE = 1;	// Space Vektor mode enable
	EvaRegs.COMCONA.bit.CLD = 0;		// CMPRx reload condition: underflow


// Initalize EVB PWM Timer
	// Action an compare output
	EvbRegs.ACTRB.bit.CMP7ACT = 2;	// Pin 7 active high
	EvbRegs.ACTRB.bit.CMP8ACT = 2;	// Pin 8 active high
	EvbRegs.ACTRB.bit.CMP9ACT = 2;	// Pin 9 active high
	EvbRegs.ACTRB.bit.CMP10ACT = 2;	// Pin 10 active high
	EvbRegs.ACTRB.bit.CMP11ACT = 2;	// Pin 11 active high
	EvbRegs.ACTRB.bit.CMP12ACT = 2;	// Pin 12 active high

	// Config of compare-control-register
	EvbRegs.COMCONB.bit.CENABLE = 1;	// Compare enable
	EvbRegs.COMCONB.bit.SVENABLE = 1;	// Space Vektor mode enable
	EvbRegs.COMCONB.bit.CLD = 0;		// CMPRx reload condition: underflow


  // Initalize EVA Timer2 
  EvaRegs.T2PR = 0x0FFF;       // Timer2 period
  EvaRegs.T2CMPR = 0x03C0;     // Timer2 compare
  EvaRegs.T2CNT = 0x0000;      // Timer2 counter
  // TMODE = continuous up/down
  // Timer enable
  // Timer compare enable
  EvaRegs.T2CON.all = 0x1042;   


	// Configuration of the dead-band generator
	// see SPRU065 for details
	// Dead-band prescaler = 16 -> f = 9.375 MHz
	// t_prescaler: 1/9.375 = 0.106 s
	// Multiplier: 9 -> 9*0.106 = 0.96 s
	EvaRegs.DBTCONA.bit.DBTPS = 4;	// Dead-band prescaler = 16
	EvaRegs.DBTCONA.bit.DBT = 9;	// Multiplier = 9

	EvbRegs.DBTCONB.bit.DBTPS = 4;	// Dead-band prescaler = 16
	EvbRegs.DBTCONB.bit.DBT = 9;	// Multiplier = 9



	// Enabeling the dead-band generator for all
	// PWM-channels. See SPRU065
	
	// dead-band timer 1-3 enable for PWM1-6
	EvaRegs.DBTCONA.bit.EDBT1 = 1;	// Dead-band Timer 1 enable
	EvaRegs.DBTCONA.bit.EDBT2 = 1;	// Dead-band Timer 2 enable
	EvaRegs.DBTCONA.bit.EDBT3 = 1;	// Dead-band Timer 3 enable

	// dead-band timer 1-3 enable for PWM8-12
	EvbRegs.DBTCONB.bit.EDBT1 = 1;	// Dead-band Timer 1 enable
	EvbRegs.DBTCONB.bit.EDBT2 = 1;	// Dead-band Timer 2 enable
	EvbRegs.DBTCONB.bit.EDBT3 = 1;	// Dead-band Timer 3 enable
}


// No ISR's used in this example


//===========================================================================
// No more.
//===========================================================================
