/*
//###########################################################################
//
// FILE:    F2812_EzDSP_RAM_lnk.cmd
//
// TITLE:   Linker Command File For F2812 eZdsp examples that run out of RAM
//          This linker file assumes the user is booting up in Jump to H0 mode
//
//###########################################################################
//
//  Ver | dd mmm yyyy | Who  | Description of changes
// =====|=============|======|===============================================
//  1.00| 11 Sep 2003 | L.H. | Changes since previous version (v.58 Alpha)
//      |             |      | Added BEGIN section to the start of H0
//      |             |      | Removed .bss, .const and .sysmem
//      |             |      |    These are for a small memory model.  All examples
//      |             |      |    use the large model.
//      |             |      | Added .esysmem section
//      |             |      | Changed ramfuncs section to load and run from RAM
//      |             |      |    (previously this was type DSECT)
//      |             |      | Moved peripheral register files to DSP28_Headers_BIOS.cmd
//      |             |      |    and DSP28_Headers_nonBIOS.cmd
//      |             |      | Added CSM_RSVD memory section in FLASHA - this region
//      |             |      |    should be programmed with all 0x0000 when using the CSM
// -----|-------------|------|-----------------------------------------------
//###########################################################################
*/

/* ======================================================
// For Code Composer Studio V2.2 and later
// ---------------------------------------
// In addition to this memory linker command file, 
// add the header linker command file directly to the project. 
// The header linker command file is required to link the
// peripheral structures to the proper locations within 
// the memory map.
//
// The header linker files are found in <base>\DSP281x_Headers\cmd
//   
// For BIOS applications add:      DSP281x_Headers_nonBIOS.cmd
// For nonBIOS applications add:   DSP281x_Headers_nonBIOS.cmd    
========================================================= */

/* ======================================================
// For Code Composer Studio prior to V2.2
// --------------------------------------
// 1) Use one of the following -l statements to include the 
// header linker command file in the project. The header linker
// file is required to link the peripheral structures to the proper 
// locations within the memory map                                    */

/* Uncomment this line to include file only for non-BIOS applications */
/* -l DSP281x_Headers_nonBIOS.cmd */

/* Uncomment this line to include file only for BIOS applications */
/* -l DSP281x_Headers_BIOS.cmd */

/* 2) In your project add the path to <base>\DSP281x_headers\cmd to the
   library search path under project->build options, linker tab, 
   library search path (-i).
/*========================================================= */



MEMORY
{
PAGE 0 :
   
   RAML1      : origin = 0x009000, length = 0x001000     /* on-chip RAM block L1 */
   ZONE6      : origin = 0x100000, length = 0x010000     /* RAM on eZdsp */
   BEGIN      : origin = 0x3F8000, length = 0x000002     /* portion of H0 we've mapped to PAGE 0 */             
   RESET      : origin = 0x3FFFC0, length = 0x000002

         
PAGE 1 : 

   RAML0       : origin = 0x008000, length = 0x001000     /* on-chip RAM block L0 */
   RAMM0       : origin = 0x000000, length = 0x000400     /* on-chip RAM block M0 */
   RAMM1       : origin = 0x000400, length = 0x000400     /* on-chip RAM block M1 */
   MATHMACRO   : origin = 0x3f9fc0, length = 0x000040     /* one DP of H0 we've mapped to PAGE 1 */
   DRAMH0      : origin = 0x3f8002, length = 0x001fbe     /* portion of H0 we've mapped to PAGE 1 */
}
 
 
SECTIONS
{
   .bss              : > RAMM0,       PAGE = 1                /* Should be empty with large memory model */
   .const            : > RAMM0,       PAGE = 1                /* Should be empty with large memory model */
   .sysmem           : > RAMM0,       PAGE = 1                /* Should be empty with large memory model */
   .cio              : > RAMM0,       PAGE = 1
   .text             : > ZONE6,       PAGE = 0
   .cinit            : > ZONE6,       PAGE = 0
   .stack            : > RAMM1,       PAGE = 1
   .ebss             : > DRAMH0,      PAGE = 1
   .econst           : > ZONE6,       PAGE = 0      
   .switch           : > ZONE6,       PAGE = 0     
   .esysmem          : > RAMM0,       PAGE = 1
   .reset            : > RESET,       PAGE = 0, TYPE = DSECT  /* we are not using the .reset section */
   codestart         : > BEGIN,       PAGE = 0                /* Used by file DSP28_CodeStartBranch.asm */
   ramfuncs          : > ZONE6,       PAGE = 0   /* dummy in RAM.cmd */
   internfuncs       : LOAD = RAML1,  PAGE = 0
   mathmacros        : > MATHMACRO,   PAGE = 1
}
